<?php
namespace webdevstudios;

/*
 * Adds the SKU for a given product to both the indexes used by Autocomplete
 * and InstantSearch.
 */
function add_product_data_to_autocomplete_and_instantsearch( $shared_attributes, $post ) {
	$product = wc_get_product( $post );

	if ( ! $product ) {
		return $shared_attributes;
	}

	// We need to make sure the SKU is a part of each index, in order to search by it.
	$shared_attributes['sku']        = $product->get_sku();

	$currency_symbol                 = html_entity_decode( get_woocommerce_currency_symbol() );
	$shared_attributes['price']      = $currency_symbol . $product->get_price();
	$shared_attributes['short_desc'] = $product->get_short_description();

	return $shared_attributes;
}
add_filter( 'algolia_post_product_shared_attributes', __NAMESPACE__ . '\add_product_data_to_autocomplete_and_instantsearch', 10, 2 );
add_filter( 'algolia_searchable_post_product_shared_attributes', __NAMESPACE__ . '\add_product_data_to_autocomplete_and_instantsearch', 10, 2 );

/*
 * Prevents a product from being indexed if it is set to be visibly hidden
 * or is not available for purchase at this time.
 *
 * Once those settings change, the product should get re-indexed automatically.
 */
function exclude_visibility_and_outofstock_products( $should_index, $post ) {

	if ( false === $should_index ) {
		return $should_index;
	}

	$product = wc_get_product( $post->ID );
	if ( ! $product ) {
		return $should_index;
	}

	$product_visibility = $product->get_catalog_visibility();
	if ( in_array( $product_visibility, [ 'catalog', 'hidden' ] ) ) {
		$should_index = false;
	}

	$stock_status = $product->get_stock_status();
	// Default WooCommerce possibilities: instock, outofstock, onbackorder
	$statuses_to_retain_indexability = [ 'instock' ];
	if ( ! in_array( $stock_status, $statuses_to_retain_indexability ) ) {
		$should_index = false;
	}

	return $should_index;
}
add_filter( 'algolia_should_index_post', __NAMESPACE__ . '\exclude_visibility_and_outofstock_products', 10, 2 );
add_filter( 'algolia_should_index_searchable_post', __NAMESPACE__ . '\exclude_visibility_and_outofstock_products', 10, 2 );

